@@ -1,6 +1,7 @@
 from asyncio import sleep
 from re import findall
 from typing import TypeVar, Union, Any, Optional, Callable
+from copy import deepcopy
 
 from discord import AutoShardedBot, Embed, Colour, PermissionOverwrite, Permissions, Guild, Member, Role, Message
 from discord.abc import PrivateChannel
@@ -42,7 +43,6 @@ class DshellInterpreteur:
             '__author_discriminator__': ctx.author.discriminator,
             '__author_bot__': ctx.author.bot,
             '__author_nick__': ctx.author.nick if hasattr(ctx.author, 'nick') else None,
-            '__author_avatar_url__': ctx.author.avatar.url if ctx.author.avatar else None,
             '__author_id__': ctx.author.id,
             '__message__': ctx.content,
             '__message_id__': ctx.id,
@@ -50,7 +50,7 @@ class DshellInterpreteur:
             '__channel_type__': ctx.channel.type.name if hasattr(ctx.channel, 'type') else None,
             '__channel_id__': ctx.channel.id,
             '__private_channel__': isinstance(ctx.channel, PrivateChannel),
-        }
+        } if ctx is not None else {}
         self.vars = vars if vars is not None else ''
         self.ctx: context = ctx
         if debug:
@@ -104,7 +104,9 @@ class DshellInterpreteur:
                 self.env[node.variable.name.value] = 0
                 for i in DshellIterator(eval_expression(node.variable.body, self)):
                     self.env[node.variable.name.value] = i
-                    await self.execute(node.body)
+                    c = deepcopy(node.body)
+                    await self.execute(c)
+                    del c
 
             elif isinstance(node, VarNode):
 
@@ -250,7 +252,7 @@ def eval_expression(tokens: list[Token], interpreter: DshellInterpreteur) -> Any
         if token.type in {DTT.INT, DTT.FLOAT, DTT.BOOL, DTT.STR, DTT.LIST, DTT.IDENT}:
             stack.append(interpreter.eval_data_token(token))
 
-        elif token.type in (DTT.MATHS_OPERATOR, DTT.LOGIC_OPERATOR):
+        elif token.type in (DTT.MATHS_OPERATOR, DTT.LOGIC_OPERATOR, DTT.LOGIC_WORD_OPERATOR):
             op = token.value
 
             if op == "not":
@@ -259,7 +261,14 @@ def eval_expression(tokens: list[Token], interpreter: DshellInterpreteur) -> Any
 
             else:
                 b = stack.pop()
-                a = stack.pop()
+                try:
+                    a = stack.pop()
+                except IndexError:
+                    if op == "-":
+                        a = 0
+                    else:
+                        raise SyntaxError(f"Invalid expression: {op} operator requires two operands, but only one was found.")
+
                 result = dshell_operators[op][0](a, b)
 
             stack.append(result)
@@ -329,6 +338,7 @@ def regroupe_commandes(body: list[Token], interpreter: DshellInterpreteur) -> li
                     type_=DTT.SEPARATOR, value=body[i].value, position=body[i].position)
                 ] + body[i + 1:], interpreter
             )  # add a sub-dictionary for sub-commands
+            i += len(body[i:])
             # return list_tokens
 
         elif (body[i].type == DTT.SEPARATOR and
@@ -401,6 +411,7 @@ def build_permission(body: list[Token], interpreter: DshellInterpreteur) -> dict
 
     for i in args_permissions:
         i.pop('*')
+        i.pop('--*')
         permissions.update(DshellPermissions(i).get_permission_overwrite(interpreter.ctx.channel.guild))
 
     return permissions
