@@ -426,7 +426,7 @@ class ParamNode(ASTNode):
         self.body = body
 
     def __repr__(self):
-        return f"<PARAM> - {self.name} *- {self.body}"
+        return f"<PARAM> - {self.body}"
 
     def to_dict(self):
         """
@@ -435,7 +435,6 @@ class ParamNode(ASTNode):
         """
         return {
             "type": "ParamNode",
-            "name": self.name.to_dict(),
             "body": [token.to_dict() for token in self.body]
         }
 
