@@ -4,7 +4,8 @@ __all__ = [
     "dshell_commands",
     "dshell_mathematical_operators",
     "dshell_logical_operators",
-    "dshell_operators"
+    "dshell_operators",
+    "dshell_logical_word_operators"
 ]
 
 from typing import Callable
@@ -27,6 +28,8 @@ dshell_commands: dict[str, Callable] = {
     "gp": dshell_get_pastbin,  # get pastbin
 
     "sm": dshell_send_message,  # send message
+    "spm": dshell_send_private_message,  # send private message
+    "srm": dshell_respond_message,  # respond to a message
     "dm": dshell_delete_message,
     "pm": dshell_purge_message,
     "em": dshell_edit_message,  # edit message
@@ -36,6 +39,15 @@ dshell_commands: dict[str, Callable] = {
     "dc": dshell_delete_channel,  # delete channel
     "dcs": dshell_delete_channels,  # delete several channels by name or regex
 
+    "gc": dshell_get_channel,  # get channel
+    "gcs": dshell_get_channels,  # get channels by name or regex
+    "gccs": dshell_get_channels_in_category,  # get channels in category
+
+    "ct": dshell_create_thread_message,  # create thread
+    "dt": dshell_delete_thread,  # delete thread
+    "gt": dshell_get_thread,  # get thread
+    "et": dshell_edit_thread,  # edit thread
+
     "bm": dshell_ban_member,  # ban member
     "um": dshell_unban_member,  # unban member
     "km": dshell_kick_member,  # kick member
@@ -58,21 +70,12 @@ dshell_commands: dict[str, Callable] = {
 
     "ar": dshell_add_reactions,  # add reactions to a message
     "rr": dshell_remove_reactions,  # remove reactions from a message
-    "cmr": dshell_clear_message_reactions,
-    "cor": dshell_clear_one_reactions
+    "cmr": dshell_clear_message_reactions, # clear reactions from a message
+    "cor": dshell_clear_one_reactions , # clear one reaction from a message
 
 }
 
 dshell_mathematical_operators: dict[str, tuple[Callable, int]] = {
-    r"<": (lambda a, b: a < b, 4),
-    r"<=": (lambda a, b: a <= b, 4),
-    r"=<": (lambda a, b: a <= b, 4),
-    r"=": (lambda a, b: a == b, 4),
-    r"!=": (lambda a, b: a != b, 4),
-    r"=!": (lambda a, b: a != b, 4),
-    r">": (lambda a, b: a > b, 4),
-    r">=": (lambda a, b: a >= b, 4),
-    r"=>": (lambda a, b: a >= b, 4),
 
     r".": (lambda a, b: a.b, 9),
     r"->": (lambda a: a.at, 10),  # equivalent to calling .at(key)
@@ -87,18 +90,31 @@ dshell_mathematical_operators: dict[str, tuple[Callable, int]] = {
     r"/": (lambda a, b: a / b, 7),
 }
 
+dshell_logical_word_operators: dict[str, tuple[Callable, int]] = {
+    r"and": (lambda a, b: bool(a and b), 2),
+    r"or": (lambda a, b: bool(a or b), 1),
+    r"not": (lambda a: not a, 3),
+    r"in": (lambda a, b: a in b, 4),
+}
+
 dshell_logical_operators: dict[str, tuple[Callable, int]] = {
 
-    r"and": (lambda a, b: bool(a and b), 2),
+    r"<": (lambda a, b: a < b, 4),
+    r"<=": (lambda a, b: a <= b, 4),
+    r"=<": (lambda a, b: a <= b, 4),
+    r"=": (lambda a, b: a == b, 4),
+    r"!=": (lambda a, b: a != b, 4),
+    r"=!": (lambda a, b: a != b, 4),
+    r">": (lambda a, b: a > b, 4),
+    r">=": (lambda a, b: a >= b, 4),
+    r"=>": (lambda a, b: a >= b, 4),
     r"&": (lambda a, b: a & b, 2),
-    r"or": (lambda a, b: bool(a or b), 1),
     r"|": (lambda a, b: a | b, 1),
-    r"in": (lambda a, b: a in b, 4),
-    r"not": (lambda a: not a, 3),
 
 }
 
 dshell_operators: dict[str, tuple[Callable, int]] = dshell_logical_operators.copy()
+dshell_operators.update(dshell_logical_word_operators)
 dshell_operators.update(dshell_mathematical_operators)
 
 '''
